@@ -91,6 +91,17 @@ macro_rules! select_view {
 #[macro_export]
 macro_rules! settings {
     ($title:expr, $save_cb:expr, $($view:expr), *) => {
+        __settings_internal!($title, "Save", $save_cb $(, $view)*)
+    };
+
+    ($title:expr, $c_bt:expr, $save_cb:expr, $($view:expr), *) => {
+        __settings_internal!($title, $c_bt, $save_cb $(, $view)*)
+    };
+}
+
+#[macro_export(local_inner_macros)]
+macro_rules! __settings_internal {
+    ($title:expr, $c_bt:expr, $save_cb:expr, $($view:expr), *) => {
         {
             use cursive::{
                 traits::{With, Scrollable},
@@ -107,14 +118,13 @@ macro_rules! settings {
                 .scroll_x(true)
             )
             .dismiss_button("Back")
-            .button("Save", $save_cb)
+            .button($c_bt, $save_cb)
             .title($title)
             .wrap_with(OnEventView::new)
             .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
         }
     };
 }
-
 /// Convenience macro that creates a horizontal layout of views
 ///
 ///  # Example
